unit uErrorHandling;

{ **************************************************************************** }
{ **************************************************************************** }

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, Buttons, ExtCtrls;

type
  TForm1 = class(TForm)
    PnlUeberschrift: TPanel;
    LblUeberschrift: TLabel;
    BitBtnAuswerten: TBitBtn;
    EdtZahlwert: TEdit;
    LblZahlwert: TLabel;
    BitBtnErneut: TBitBtn;
    BitBtnInformation: TBitBtn;
    BitBtnSchliessen: TBitBtn;
    GrpBoxEingabe: TGroupBox;
    GrpBoxAusgabe: TGroupBox;
    EdtAuswertung: TEdit;
    LblAuswertung: TLabel;
    procedure BitBtnAuswertenClick(Sender: TObject);
    procedure EdtZahlwertKeyPress(Sender: TObject; var Key: Char);
    procedure BitBtnErneutClick(Sender: TObject);
    procedure BitBtnInformationClick(Sender: TObject);
    procedure BitBtnSchliessenClick(Sender: TObject);
  private
    { Private-Deklarationen }
  public
    { Public-Deklarationen }
  end;

var
  Form1: TForm1;

{ **************************************************************************** }
{ **************************************************************************** }

implementation

{$R *.dfm}

procedure TForm1.EdtZahlwertKeyPress(Sender: TObject; var Key: Char);
begin
  { Error-Handling 1:
    Siehe Eigenschaft "MaxLength" von "EdtZahlwert": diese ist auf "3" gesetzt, damit nur
    Eingabe einer Lnge von max. 3 Zeichen mglich sind. }

  { Error-Handling 2:
    Falsche Eingaben (--> keine Zahlwerte) werden bei der Eingabe abgefangen. Wenn Tastendruck
    keine Ziffer oder Backspace (#8) ist, wird die Tasteneingabe "geloescht" (#0); Tabulator,
    Enter, Cursortasten, Einfuegen, Entfernen, Pos1 und Ende sind unabhaengig immer davon nutzbar. }
  if not (Key in ['0'..'9',#8]) then Key := #0;
end;

{ **************************************************************************** }

procedure TForm1.BitBtnAuswertenClick(Sender: TObject);
var
  Zahlwert: Integer;
begin
  Zahlwert := StrToInt(EdtZahlwert.Text);

  { Error-Handling 3:
    Falsche Zahlwerte werden mit einer Fehlermeldung zurueckgewiesen... }
  if (Zahlwert < 0) or (Zahlwert > 100) then begin
    MessageDlg('Fehlerhafte Eingabe.' + #13 +
      'Bitte geben Sie einen Wert zwischen 0 und 100 ein.',mtError,[mbOK],0);
    { ...und anschliessend im Edit "EdtZahlwert" geloescht. }
    EdtZahlwert.Text := '';
  end
  else begin  { Situation: eine gueltige Eingabe }
    if Zahlwert mod 2 = 0 then EdtAuswertung.Text := 'Die Zahl ist gerade.'
      else EdtAuswertung.Text := 'Die Zahl ist ungerade.';
    { Error-Handling 4.1:
      Komponenten (ent-)sperren, die in bestimmten Situationen nicht aktiv sein sollen. }
    EdtZahlwert.ReadOnly := True;
    BitBtnAuswerten.Enabled := False;
  end;

  { Error-Handling 5:
    Siehe Eigenschaft "ReadOnly" von "EdtAuswertung": diese ist auf "True" gesetzt, damit
    - sofern vom Programmierer erwnscht - der User die Ausgabe nicht ndern kann. }
end;

{ **************************************************************************** }

procedure TForm1.BitBtnErneutClick(Sender: TObject);
begin
  EdtZahlwert.Text := '';
  EdtAuswertung.Text := '';

  { Error-Handling 4.2:
    Komponenten (ent-)sperren, die in bestimmten Situationen nicht aktiv sein sollen. }
  EdtZahlwert.ReadOnly := False;
  BitBtnAuswerten.Enabled := True;
end;

{ **************************************************************************** }

procedure TForm1.BitBtnInformationClick(Sender: TObject);
begin
  MessageDlg('Error-Handling (V1.0)' + #13 +
    'Kleines Demonstrationsprogramm zu grundlegendem Error-Handling.' + #13 + #13 +
    'M. Zirbes, 2009' + #13 + #13 +
    'Bei diesem Programm handelt es sich um Freeware,' + #13 +
    'd.h. es steht zur kostenlosen Nutzung frei zur Verfgung' + #13 +
    'und darf ohne Entgelt vervielfltigt und verbreitet werden.' + #13 + #13 +
    'Kontakt: schule@mijozi.de',mtInformation,[mbOK],0);
end;

{ **************************************************************************** }

procedure TForm1.BitBtnSchliessenClick(Sender: TObject);
begin
  Close;
end;

{ **************************************************************************** }
{ **************************************************************************** }

end.
